#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_REVERSE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_REVERSE_HPP_INCLUDED

#include <boost/simd/swar/include/functions/scalar/reverse.hpp>

#endif
